@@ -23,7 +23,9 @@ chk_identical <- function(x, y, x_name = NULL) {
   }
   if (is.null(x_name)) x_name <- deparse_backtick_chk(substitute(x))
   y_name <- as_label(y)
-  abort_chk(x_name, " must be identical to: ", y_name, x = x, y = y)
+  obj_of <- if(grepl("^<", y_name)) "the y object of class " else NULL
+  abort_chk(x_name, " must be identical to ",
+            obj_of, y_name, x = x, y = y)
 }
 
 #' @describeIn chk_identical Validate Identical
@@ -32,4 +34,3 @@ chk_identical <- function(x, y, x_name = NULL) {
 #' vld_identical(1, 1)
 #' @export
 vld_identical <- function(x, y) identical(x, y)
-
